@@ -6,4 +6,5 @@ Created on Fri Jul 30 13:22:34 2021
 """
 
 from .technical_analysis import *
-from .backtest import simple_test
+from .simpletest import *
+from .backtest import *
